import { Events } from './constants';
import { SecureInput } from './input';
import type { ClickToPayInstance, ClickToPayOptions, CombinedEvents, Config, Field } from './types';
declare global {
    interface Window {
        SECURE_FIELDS_FRAME_URL?: string;
        CLICK_TO_PAY_FRAME_URL?: string;
    }
}
declare class SecureFields {
    config: Config;
    controller: HTMLIFrameElement;
    frameUrl: string;
    apiUrl: string;
    parentOrigin: string;
    font: string;
    cardNumber: SecureInput;
    securityCode: SecureInput;
    expiryDate: SecureInput;
    method: 'card' | 'click-to-pay';
    private clickToPayInstance?;
    clickToPay?: ClickToPayInstance;
    environmentPath: string;
    /**
     * CARD_VAULT_SUCCESS: Triggered when the card is successfully vaulted.
     *
     * CARD_VAULT_FAILURE: Triggered when the card vaulting fails.
     *
     * FORM_CHANGED: Triggered when the form is changed.
     *
     * READY: Triggered when the SecureFields is loaded and ready to be used.
     */
    static get Events(): typeof Events;
    static get version(): string;
    constructor(config: Config);
    update(property: string, value: unknown): void;
    updateMethod(value: string, { data }: {
        data: any;
    }): void;
    private _addField;
    addCardNumberField(element: string | HTMLElement, options?: Omit<Field, 'element' | 'type'>): SecureInput;
    addSecurityCodeField(element: string | HTMLElement, options?: Omit<Field, 'element' | 'type'>): SecureInput;
    addExpiryDateField(element: string | HTMLElement, options?: Omit<Field, 'element' | 'type'>): SecureInput;
    addClickToPay(element: string | HTMLElement, options?: ClickToPayOptions): Promise<ClickToPayInstance>;
    addEventListener(event: CombinedEvents, callback: (...args: any[]) => void): void;
    removeEventListener(event: CombinedEvents, callback: (...args: any[]) => void): void;
    submit(): void;
    setDebug(debug: boolean): void;
    addFont(font: string): void;
}
export { SecureFields, SecureInput, Events };
export type { ClickToPayInstance, ClickToPayOptions, Config, CombinedEvents, Field, FieldType, FieldEvent, Styles, StylesTuple, FormChangeEventData, } from './types';
