import { Events } from './constants';
import type * as CSS from 'csstype';
export type Config = {
    environment?: 'sandbox' | 'production';
    gr4vyId: string;
    paymentMethodId?: string;
    sessionId: string;
};
export type InputConfig = {
    frameUrl: string;
    parentOrigin: string;
    font?: string;
    options: Field;
};
export type FieldType = 'number' | 'securityCode' | 'expiryDate';
export type Field = {
    type: FieldType;
    placeholder?: string;
    styles?: Styles;
    label?: string;
    lengths?: Array<number>;
    size?: number;
};
export type FieldEvent = {
    type: keyof HTMLElementEventMap;
    data: Omit<Field, 'type' | 'styles'> & {
        id: Field['type'];
        valid: boolean;
        autofilled: boolean;
    };
};
export type CombinedEvents = Events | keyof HTMLElementEventMap;
export type Event = Events | `${FieldType}:${keyof HTMLElementEventMap}`;
export type SupportedCSSProperties = Partial<Pick<CSS.Properties, 'backgroundColor' | 'boxShadow' | 'caretColor' | 'color' | 'colorScheme' | 'cursor' | 'font' | 'fontFamily' | 'fontFeatureSettings' | 'fontKerning' | 'fontSize' | 'fontSizeAdjust' | 'fontStretch' | 'fontStyle' | 'fontVariant' | 'fontVariantAlternates' | 'fontVariantCaps' | 'fontVariantEastAsian' | 'fontVariantLigatures' | 'fontVariantNumeric' | 'fontVariationSettings' | 'fontWeight' | 'letterSpacing' | 'lineHeight' | 'opacity' | 'padding' | 'textAlign' | 'textShadow' | 'textRendering' | 'transition' | 'MozOsxFontSmoothing' | 'WebkitFontSmoothing'>>;
export type SupportedCSSVariables = {
    [K in keyof SupportedCSSProperties as `--${K}`]: SupportedCSSProperties[K];
};
export type Styles = {
    [key in ':autofill' | ':hover' | ':focus' | ':disabled' | ':valid' | ':invalid' | '::placeholder']?: SupportedCSSProperties;
} & SupportedCSSProperties;
export type StylesTuple = [string, string][];
export type FormChangeEventData = {
    fields: {
        number: {
            valid: boolean;
            empty: boolean;
            autofilled: boolean;
        };
        expiryDate: {
            valid: boolean;
            empty: boolean;
            autofilled: boolean;
        };
        securityCode: {
            valid: boolean;
            empty: boolean;
            autofilled: boolean;
        };
    };
    complete: boolean;
};
export type ClickToPayOptions = {
    srcDpaId?: string;
    dpaName?: string;
    cardBrands: Array<'mastercard' | 'maestro' | 'visa' | 'amex' | 'discover'>;
    dpaLocale: string;
    cardForm?: string | HTMLElement;
    signIn?: string | HTMLElement;
    consentCheckbox?: string | HTMLElement;
    learnMoreLink?: string | HTMLElement;
    email?: string;
    mobileNumber?: {
        countryCode: string;
        phoneNumber: string;
    };
    dynamicDataType?: 'NONE' | 'CARD_APPLICATION_CRYPTOGRAM_SHORT_FORM';
};
export type ClickToPayInstance = {
    element: HTMLElement;
    options: ClickToPayOptions;
    signIn: ({ email, mobileNumber, }: Partial<Pick<ClickToPayOptions, 'email' | 'mobileNumber'>>) => Promise<void>;
    signOut: () => Promise<void>;
};
